@@ -386,7 +386,6 @@ def fun_control_init(
                 'path': None,
                 'prep_model': None,
                 'prep_model_name': None,
-                'save_model': False,
                 'scenario': "lightning",
                 'seed': 1234,
                 'show_batch_interval': 1000000,
@@ -485,7 +484,6 @@ def fun_control_init(
         "progress_file": progress_file,
         "save_experiment": save_experiment,
         "save_result": save_result,
-        "save_model": False,
         "scaler": scaler,
         "scaler_name": scaler_name,
         "scenario": scenario,
@@ -721,14 +719,14 @@ def surrogate_control_init(
     method="regression",
     model_optimizer=differential_evolution,
     model_fun_evals=10000,
-    min_theta=-3.0,
-    max_theta=2.0,
+    min_theta=-3.0,  # log10
+    max_theta=2.0,  # log10
     n_theta="anisotropic",
     p_val=2.0,
     n_p=1,
     optim_p=False,
-    min_Lambda=1e-9,
-    max_Lambda=1,
+    min_Lambda=-9,  # log10
+    max_Lambda=0,  # log10
     seed=124,
     theta_init_zero=False,
     var_type=None,
